<?

class DimbalPopupAdmin{

	public static $settings;

	const OPTIONS_NAME = "dimbal_social_popup_options";
	
	public static function get_default_settings_array(){
		$defaults = array(
			'active'=>true,
			'credit'=>true,
			'cooldown_minutes'=>60,
			'initial_delay'=>1000,
			'fade_in_delay'=>500,
			'fade_out_delay'=>100,
			'content'=>'',
		);
		return $defaults;
	}

	public static function get_settings(){
		if(!isset(self::$settings)){
			self::$settings = get_option(self::OPTIONS_NAME);	
		}
		if(!is_array(self::$settings)){
			self::$settings = self::get_default_settings_array();
		}
		return self::$settings;
	}
	
	public static function save_settings($settings){
		//Create the initial defaults
		$defaults = self::get_default_settings_array();
		
		//Get the existing settings
		$current_settings = self::get_settings();
		
		//First save the defaults, then override with current settings, then override with new settings
		$settings = array_merge($defaults, $current_settings, $settings);
		update_option(self::OPTIONS_NAME, $settings);
		self::$settings = $settings;
	}
	
	public static function save_options_page(){
		$settings = self::get_settings();
		
		// Process the Boolean Based form options
		$booleans = array('active','credit');
		foreach($booleans as $item){
			$keyname = 'dimbal_popup_options_'.$item;
			if(array_key_exists($keyname, $_REQUEST)){
				$value = $_REQUEST[$keyname];
				if($value == 'checked'){
					$settings[$item]=true;
				}else{
					$settings[$item]=false;
				}
			}else{
				$settings[$item]=false;
			}	
		}
		
		// Process the Integer Based form options
		$integers = array('cooldown_minutes','initial_delay','fade_in_delay','fade_out_delay');
		foreach($integers as $item){
			$keyname = 'dimbal_popup_options_'.$item;
			if(array_key_exists($keyname, $_REQUEST)){
				$value = $_REQUEST[$keyname];
				//if(is_integer($value)){
					$settings[$item]=$value;
				//}
			}
		}
		
		//Process the Text Based form options
		$texts = array('content');
		foreach($texts as $item){
			$keyname = 'dimbal_popup_options_'.$item;
			if(array_key_exists($keyname, $_REQUEST)){
				$value = $_REQUEST[$keyname];
			}else{
				$value = '';
			}
			$settings[$item]=$value;
		}
		
		self::save_settings($settings);
		
		echo showMessage("Settings updated.");
		
	}
	
	public static function draw_options_page() {
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}
		
		//First check and see if the form was submitted and needs to be saved
		if(array_key_exists('dimbal_popup_options_submit', $_REQUEST)){
			self::save_options_page();
		}
		
		$settings = self::get_settings();
		$key_base = "dimbal_popup_options_";
		
		?>
		<div style="float:right; margin: 10px 10px 0 0"><a href="http://www.dimbal.com"><img src="http://www.dimbal.com/images/logo_300.png" alt="Dimbal Software" /></a></div>
		<h1>Dimbal Popups</h1>
		<p style="font-style:italic; font-size:larger;">Easily add a Popup to your posts to encourage your users to share your pages content.</p>
		<hr />
		<div style="display:table; width:100%;">
			<div style="display:table-cell; width:auto; vertical-align:top;">
				
				<!-- LEFT SIDE CONTENT -->
				<h2>Popup Settings</h2>
				<form action="#" method="post">
					<table class="dimbal_popup_options_table">
						<tr>
							<td>
								<div class="dimbal_popup_options_title">Popup Activated</div>
								<div class="dimbal_popup_options_help">Determines whether or not the popup is activated.</div>
							</td>
							<td>
								<?
									$selected = '';
									if($settings['active'] == true){
										$selected = ' checked';
									}
								?>
								<input type="checkbox" name="<?=($key_base)?>active"<?=($selected)?> value="checked" />
							</td>
						</tr>
						<tr>
							<td>
								<div class="dimbal_popup_options_title">Cooldown for 2nd Display</div>
								<div class="dimbal_popup_options_help"># of Minutes that should pass before showing the popup again to the same user. (recommended 60 mins)</div>
							</td>
							<td>
								<input type="text" name="<?=($key_base)?>cooldown_minutes" value="<?=($settings['cooldown_minutes'])?>" />
							</td>
						</tr>
						<tr>
							<td>
								<div class="dimbal_popup_options_title">Initial Delay</div>
								<div class="dimbal_popup_options_help"># of Milliseconds that should pass before showing the popup. (recommended 1000 ms)</div>
							</td>
							<td>
								<input type="text" name="<?=($key_base)?>initial_delay" value="<?=($settings['initial_delay'])?>" />
							</td>
						</tr>
						<tr>
							<td>
								<div class="dimbal_popup_options_title">Fade-In Duration</div>
								<div class="dimbal_popup_options_help"># of Milliseconds that it should take to fade in the popup. (recommended 500 ms)</div>
							</td>
							<td>
								<input type="text" name="<?=($key_base)?>fade_in_delay" value="<?=($settings['fade_in_delay'])?>" />
							</td>
						</tr>
						<tr>
							<td>
								<div class="dimbal_popup_options_title">Fade-Out Duration</div>
								<div class="dimbal_popup_options_help"># of Milliseconds that it should take to fade out the popup. (recommended 250 ms)</div>
							</td>
							<td>
								<input type="text" name="<?=($key_base)?>fade_out_delay" value="<?=($settings['fade_out_delay'])?>" />
							</td>
						</tr>
						<!--<tr>
							<td>
								<div class="dimbal_popup_options_title">Show Credit</div>
								<div class="dimbal_popup_options_help">Help support this plugin.</div>
							</td>
							<td>
								<?
									$selected = '';
									if($settings['credit'] == true){
										$selected = ' checked';
									}
								?>
								<input type="checkbox" name="<?=($key_base)?>credit"<?=($selected)?> value="checked" />
							</td>
						</tr>-->
						<!--<tr>
							<td>
								<div class="dimbal_popup_options_title">Custom Content</div>
								<div class="dimbal_popup_options_help">If desired, you can overwrite the social share content with your custom content.</div>
							</td>
							<td></td>
						</tr>-->
						<tr>
							<td colspan="2"><input type="submit" name="<?=($key_base)?>submit" value="Save Options" /></td>
						</tr>
					</table>
				</form>
			</div>
			<br />
			<hr />
			<br />
			<div style="display:table-cell; width:300px; padding-left:20px; vertical-align:top;">
				<!-- RIGHT SIDE CONTENT -->
				<h4>Did you like this Plugin?  Please help it grow.</h4>
				<div style="text-align:center;"><a href="http://wordpress.org/support/view/plugin-reviews/dimbal-social-popup">Rate this Plugin on Wordpress</a></div>
				<br />
				<div style="text-align:center;">
					<form action="https://www.paypal.com/cgi-bin/webscr" method="post" target="_top">
					<input type="hidden" name="cmd" value="_s-xclick">
					<input type="hidden" name="hosted_button_id" value="5GMXFKZ79EJFA">
					<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
					<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
					</form>
				</div>
				<hr />
				<h4>Follow us for Free Giveaways and more...</h4>
				<div id="fb-root"></div>
				<script type="text/javascript">
				  // Additional JS functions here
				  window.fbAsyncInit = function() {
				    FB.init({
				      appId      : '539348092746687', // App ID
				      //channelUrl : '//<?=(URL_ROOT)?>channel.html', // Channel File
				      status     : true, // check login status
				      cookie     : true, // enable cookies to allow the server to access the session
				      xfbml      : true,  // parse XFBML
				      frictionlessRequests: true,  //Enable Frictionless requests
				    });
				  };
	
				  // Load the SDK Asynchronously
				  (function(d){
				     var js, id = 'facebook-jssdk', ref = d.getElementsByTagName('script')[0];
				     if (d.getElementById(id)) {return;}
				     js = d.createElement('script'); js.id = id; js.async = true;
				     js.src = "//connect.facebook.net/en_US/all.js";
				     ref.parentNode.insertBefore(js, ref);
				   }(document));
				</script>
				<div style="text-align:center;"><div class="fb-like" data-href="https://www.facebook.com/dimbalsoftware" data-send="false" data-layout="standard" data-show-faces="false" data-width="200"></div></div>
				<hr />
				<h4>Questions?  Support?  Record a Bug?</h4>
				<p>Need help with this plugin? Visit...</p>
				<p><a href="http://www.dimbal.com/support">http://www.dimbal.com/support</a></p>
				<hr />
			</div>
		</div>
		<?
	}
	
}