<?php
/* 
 * Plugin Name:   Dimbal Social Popup
 * Version:       1.2.0
 * Plugin URI:    http://www.dimbal.com/
 * Description:   Add this plugin to show a Social Sharing Popup for your posts
 * Author:        Ben Hall
 * Author URI:    http://www.benhallbenhall.com/
 */
if ( ! defined( 'ABSPATH' ) ) exit();	// sanity check

//error_reporting(E_ALL);
//ini_set('display_errors','On');

//Include the classes
include_once(dirname(__FILE__) . '/class.DimbalPopupAdmin.php');
include_once(dirname(__FILE__) . '/class.DimbalSocialSharing.php');

//////////////////////////////////////////////////////////////////////////////////////////////
////  PLUGIN ACTIVATION
//////////////////////////////////////////////////////////////////////////////////////////////

//Function that is run when the plugin is activated
register_activation_hook(__FILE__, 'dimbal_popup_activate');
function dimbal_popup_activate(){
	//Save default settings
	DimbalPopupAdmin::save_settings(array());
}


//////////////////////////////////////////////////////////////////////////////////////////////
////  POPUP DISPLAY
//////////////////////////////////////////////////////////////////////////////////////////////

// Add a filter to add the popup code into the content
add_filter( 'the_content', 'dimbal_popup_add_content' );


//Display the Popup to the user
function dimbal_popup_add_content($content){

	//Get / Setup needed data
	global $post, $posts;
	$settings = DimbalPopupAdmin::get_settings();
	
	if(count($posts) > 1){
		//This means it is a batch and not a single item... we should nto show the popup. 
	}elseif($settings['active']==true){
		$newContent = '';
		$attributes = array('credit','cooldown_minutes','initial_delay','fade_in_delay','fade_out_delay');
		$attribute_string = '';
		foreach($attributes as $attribute){
			$attribute_string .= ' dp_'.$attribute.'="'.$settings[$attribute].'"';
		}
		$newContent .= '<div id="dimbal_popup_wrapper"></div>';	//Can add an admin option here to not display this gray overlay
		$newContent .= '<div id="dimbal_popup_container" '.$attribute_string.'>';
			
			$newContent .= '<img id="dimbal_popup_close_icon" src="'.plugins_url( 'cancel.png' , __FILE__ ).'" onclick="javascript:dimbal_popup_close(\'dimbal_popup_wrapper\');dimbal_popup_close(\'dimbal_popup_container\');" />';
			
			//get the image information
			$thumbnail = get_post_thumbnail_id($post->id);
			if(!empty($thumbnail)){
				$thumbnail = the_attachment_link( $thumbnail->ID, false );
			}else{
				//Featured image not defined -- let's get an image manually if possible
				$code_output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
			    if (isset($matches [1] [0])) {
			        $thumbnail = $matches [1] [0];
			    }
			}
			
			//get the title information
			$title = get_the_title($post->id);
			$url = get_permalink($post->id);
			
			//Prepare the Social Buttons
			$social_buttons = array(
				"sn"=>"",
				"title"=>$title,
				"description"=>"",
				"url"=>$url,
				"img"=>$thumbnail
			);
			
			$newContent .= '<div id="dimbal_popup_content_wrapper">';
				if(!empty($thumbnail)){
					$newContent .= '<div id="dimbal_popup_content_left">';
						$newContent .= '<img src="'.$thumbnail.'" alt="'.$title.'" />';
					$newContent .= '</div>';
				}
				$newContent .= '<div id="dimbal_popup_content_right">';
					$newContent .= '<h2 id="dimbal_popup_content_title">'.$title.'</h2>';
					$newContent .= '<p>Share this with Family and Friends:</p>';
					$newContent .= DimbalSocialSharing::buildSocialBox(array_merge($social_buttons,array('sn'=>'facebook')));
					$newContent .= DimbalSocialSharing::buildSocialBox(array_merge($social_buttons,array('sn'=>'twitter')));
					$newContent .= DimbalSocialSharing::buildSocialBox(array_merge($social_buttons,array('sn'=>'pintrest')));
					$newContent .= DimbalSocialSharing::buildSocialBox(array_merge($social_buttons,array('sn'=>'google')));
				$newContent .= '</div>';
			$newContent .= '</div>';
		
		$newContent .= '</div>';
		
		
		$content = $content . $newContent;
		
		//Need to also add or enqueu the JS file... currently it will just add the code to the post
		wp_register_script( 'dimbal_popup_script', plugins_url( '/dimbal_popup.js', __FILE__ ) );
		wp_enqueue_script( 'dimbal_popup_script' );
			
		//Need to also add the CSS styles for this block of code
		wp_register_style( 'dimbal_popup_stylesheet', plugins_url('/dimbal_popup.css', __FILE__) );
		wp_enqueue_style( 'dimbal_popup_stylesheet' );
	}
	
	return $content;
}



//////////////////////////////////////////////////////////////////////////////////////////////
////  ADMIN PAGES
//////////////////////////////////////////////////////////////////////////////////////////////


//ADMIN MENU PAGE
add_action( 'admin_menu', 'dimbal_popup_plugin_menu' );

//This function registers the various admin pages into Wordpress
function dimbal_popup_plugin_menu() {
	add_options_page( 'Dimbal Social Popup Settings', 'Dimbal Social Popup', 'manage_options', 'dimbal-popup-plugin', 'dimbal_popup_page_options' );
}

//This function displays the Primary Admin Page
function dimbal_popup_page_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	wp_register_style( 'dimbal_popup_admin_stylesheet', plugins_url('/admin.css', __FILE__) );
	wp_enqueue_style( 'dimbal_popup_admin_stylesheet' );
	DimbalPopupAdmin::draw_options_page();
}




function showMessage($message, $errormsg = false){
	if ($errormsg) {
		echo '<div id="message" class="error">';
	}else{
		echo '<div id="message" class="updated fade">';
	}
	echo "<p><strong>$message</strong></p></div>";
} 